@@ -1,7 +1,7 @@
 ## File Name: mice.impute.weighted.norm.R
-## File Version: 0.30
+## File Version: 0.402
 
-mice.impute.weighted.norm <- function(y, ry, x, ridge=.00001, pls.facs=NULL,
+mice.impute.weighted.norm <- function(y, ry, x, wy=NULL, ridge=.00001, pls.facs=NULL,
     imputationWeights=NULL, interactions=NULL, quadratics=NULL, ... )
 {
     # processing
@@ -19,7 +19,9 @@ mice.impute.weighted.norm <- function(y, ry, x, ridge=.00001, pls.facs=NULL,
     if ( is.null(pls.facs) ){
         parm <- mice_imputation_weighted_norm_draw( yobs=yobs, xobs=xobs,
                         ry=ry, y=y, x=x, weights.obs=weights.obs, ... )
-        yimp <- x[!ry,  ] %*% parm$beta + stats::rnorm(sum(!ry)) * parm$sigma
+        wy <- mice_imputation_define_wy(wy=wy, ry=ry)
+        yimp <- x[wy,  ] %*% parm$beta + stats::rnorm(sum(wy)) * parm$sigma
+        yimp <- yimp[,1]
     }
     return(yimp)
 }
